# Copyright (C) 2021-2022 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

#LIC_FILES_CHKSUM = "file://COPYING;md5=6bc538ed5bd9a7fc9398086aedcd7e46"

FILESEXTRAPATHS_prepend := "${THISDIR}/${PN}:"
PATCHTOOL = "git"

#SRCREV = "a68e31b63f864ff71cd4adb40fbc9e1edc75c250"

KERNEL_IMAGETYPE += "Image.gz"

python () {
    if d.getVar('MACHINE') == 'mpxls1028crx07':
        d.setVar('PLATFORM', '${MACHINE}')
    elif d.getVar('MACHINE') == 'mpxlx2160acrx08':
        d.setVar('PLATFORM', '${MACHINE}')
    elif d.getVar('MACHINE') == 'mpxlx2160acrx08ai':
        d.setVar('PLATFORM', 'mpxlx2160acrx08')
    else:
        d.setVar('PLATFORM', 'mpxls10xx')
}

ITS_DEVICETREE_CFG ?= "${ITS_DEVICETREE_CONFIG}"

do_install_append() {
    install -d ${DEPLOY_DIR_IMAGE}
    if [ -f "arch/${ARCH}/boot/Image" ]; then
        install -m 0644 arch/${ARCH}/boot/Image ${D}/boot/Image-${KERNEL_VERSION}
        ln -sf  Image-${KERNEL_VERSION} ${D}/boot/Image
    fi
    its_file=${S}/kernel-${PLATFORM}.its
    if [ ! -f ${its_file} ]; then
        its_file = ${S}/kernel-mpxls10xx.its
    fi
    default="            default = \"${ITS_DEVICETREE_CFG}\";"
    if [ -n "${ITS_DEVICETREE_CFG}" ]; then
        sed -e "s/^ *default *=.*$/${default}/g" ${its_file} > kernel-${PLATFORM}.its
    else
        cp ${its_file} kernel-${PLATFORM}.its
    fi
    mkimage -f kernel-${PLATFORM}.its fitImage.itb
    install -m 0644 fitImage.itb ${D}/boot/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${D}/boot/fitImage.itb

    bbdebug 1 "Deploying fitImage-${KERNEL_VERSION}.itb\n"
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb
}

do_deploy_append() {
    install -d ${DEPLOY_DIR_IMAGE}
    bbdebug 1 "Deploying fitImage-${KERNEL_VERSION}.itb\n"
    install -m 0644 ${D}/boot/fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage-${KERNEL_VERSION}.itb
    ln -sf fitImage-${KERNEL_VERSION}.itb ${DEPLOY_DIR_IMAGE}/fitImage.itb
}

FILES_${KERNEL_PACKAGE_NAME}-image += "/boot/Image*"
FILES_${KERNEL_PACKAGE_NAME}-image-fitimage += "/boot/fitImage*"

PACKAGES += "${PN}-images"
FILES_${PN}-images += "/boot"
COMPATIBLE_MACHINE = "(qoriq)"

FILES_${PN} += "/boot/fitImage*"

SRC_URI += "file://0001-mpxlxxx-added-default-configurations.patch;name=patch0001"
SRC_URI += "file://0002-mpxlxxx-added-device-trees.patch;name=patch0002"
SRC_URI += "file://0003-its-added-ITS-files-for-MPX-COMe.patch;name=patch0003"
SRC_URI += "file://0004-mmc-host-sdhci-of-esdhc-adjusted-clocking.patch;name=patch0004"
SRC_URI += "file://0005-spi-spi-nor-updated-configuration.patch;name=patch0005"
SRC_URI += "file://0006-fxl6408-added-driver.patch;name=patch0006"
SRC_URI += "file://0007-rtc-pcf85063-added-IRQ-handling.patch;name=patch0007"
SRC_URI += "file://0008-drivers-rtc-driver-for-Micro-Crystal-RV8564.patch;name=patch0008"
SRC_URI += "file://0009-net-phy-re-worked-interrupt-support.patch;name=patch0009"
SRC_URI += "file://0010-net-phy-merge-fixes-for-Marvell-PHYs.patch;name=patch0010"
SRC_URI += "file://0011-hwmon-lm90-support-for-extended-temperature-mode.patch;name=patch0011"
SRC_URI += "file://0012-drivers-spi-added-fsl-sja1105-as-know-device-ID-for-.patch;name=patch0012"
SRC_URI += "file://0013-net-phy-dp83867-added-loopback-feature.patch;name=patch0013"
SRC_URI += "file://0014-of-irq-fixed-missing-export-of-of_irq_count.patch;name=patch0014"
SRC_URI += "file://0015-Added-Support-for-CAUI-PHY-Interface-mode.patch;name=patch0015"
SRC_URI += "file://0016-localversion-3.0.patch;name=patch0016"
SRC_URI += "file://0017-Added-CAN-support-to-defconfig.patch;name=patch0017"
SRC_URI += "file://0018-mpxlx2160-Updated-defconfig-updated-config-for-kerne.patch;name=patch0018"
SRC_URI += "file://0019-mpxlx2160-updated-device-tree.patch;name=patch0019"
SRC_URI += "file://0020-its-Changed-kernel-loadaddress.patch;name=patch0020"
SRC_URI += "file://0021-configs-mpxls10xx_defconfig-updated.patch;name=patch0021"
SRC_URI += "file://0022-mpxls1028-Updated-Kernel-Load-address.patch;name=patch0022"
SRC_URI += "file://0023-mpxls1046-mpxls1088-mpxls1043-Updated-Kernel-Load-ad.patch;name=patch0023"
SRC_URI += "file://0024-dts-mpxls1043-update-USB-nodes-status.patch;name=patch0024"
SRC_URI += "file://0025-dts-mpxls1088-crx06-tsn-fixed-sja1105-compatible-str.patch;name=patch0025"
SRC_URI += "file://0026-its-fixed-mkimage-verify-header-error.patch;name=patch0026"
SRC_URI += "file://0027-kernel-mpxls10xx.its-fixed-naming-convention-mpxls10.patch;name=patch0027"
SRC_URI += "file://0028-localversion-microsys-update-3.1.patch;name=patch0028"
SRC_URI += "file://0029-disabled-sja1105-driver-in-devicetree-both-sja1105t-.patch;name=patch0029"
SRC_URI += "file://0030-fix-name-for-mpxls1088crx05-in-.its-file.patch;name=patch0030"
SRC_URI += "file://0031-its-mpxls10xx-fixed-kernel-address.patch;name=patch0031"
SRC_URI += "file://0032-net-phy-marvell.c-fixed-LED-setup.patch;name=patch0032"
SRC_URI += "file://0033-dts-mpxls1088_crx05-added-PCS-PHY-handles.patch;name=patch0033"
SRC_URI += "file://0034-configs-mpxls10xx-updated-configuration.patch;name=patch0034"
SRC_URI += "file://0035-localversion-update-4.0.patch;name=patch0035"
SRC_URI += "file://0036-dts-mpxls1088-fixed-mdio-alias.patch;name=patch0036"
SRC_URI += "file://0037-config-mpxls10xx-updated-with-WiFi.patch;name=patch0037"

SRC_URI[patch0001.md5sum] = "5a54c669cedd3bddb8ab20df75e32ef0"
SRC_URI[patch0002.md5sum] = "5b75c826015b4ba19f8620429fce72f7"
SRC_URI[patch0003.md5sum] = "55d30215d68a92d9f4ee0aabb95b19b5"
SRC_URI[patch0004.md5sum] = "19b3827a8312cc6cfd2e532942c81871"
SRC_URI[patch0005.md5sum] = "7c689154119887f34917a9f5d79fa861"
SRC_URI[patch0006.md5sum] = "da7acd7595e0ce3e803f5fdfe61a4444"
SRC_URI[patch0007.md5sum] = "d5f5b37456a3a45e5cfe1b6653622a45"
SRC_URI[patch0008.md5sum] = "b56aa78c7cf4e03f9938be4b60eb5149"
SRC_URI[patch0009.md5sum] = "4bb364cdc680e0c5e1e4a5b53d5b1e76"
SRC_URI[patch0010.md5sum] = "fc4925150f1ed681d8c66fb9c89cd82e"
SRC_URI[patch0011.md5sum] = "22ed16e4d0767aa225989791006ea596"
SRC_URI[patch0012.md5sum] = "d2a3140528f7bb2e1aa210d4fc9c01c0"
SRC_URI[patch0013.md5sum] = "bb2b3d7d4050c4b3b8605a8eb8cc98ac"
SRC_URI[patch0014.md5sum] = "b7063fe44de134f5f0be861d39db8879"
SRC_URI[patch0015.md5sum] = "248a98234928c2ef2a3b291fc63932e9"
SRC_URI[patch0016.md5sum] = "7ff7e1870b895d9e00eff0f39b48e020"
SRC_URI[patch0017.md5sum] = "10a256e735993e66b5a6b8c825bd5819"
SRC_URI[patch0018.md5sum] = "4c5e88ffef5577cd83993fa676d439be"
SRC_URI[patch0019.md5sum] = "c57bc123340a6b5f65f1d56dfca5c52e"
SRC_URI[patch0020.md5sum] = "1ad92b10f98052e8448076b07b55501e"
SRC_URI[patch0021.md5sum] = "b78ada4e6c218655bc35c589b335276d"
SRC_URI[patch0022.md5sum] = "2d9941b82800b05838ee5b705b6eb6f8"
SRC_URI[patch0023.md5sum] = "337fdff2b5a5c0d890096acdc0d5e248"
SRC_URI[patch0024.md5sum] = "a3ad3d0b81f0687c8ad065526fae2af0"
SRC_URI[patch0025.md5sum] = "b061a4c0a66ec7019ea0e46596416702"
SRC_URI[patch0026.md5sum] = "4c33cc782072a01b9a21146b5f3d7052"
SRC_URI[patch0027.md5sum] = "125f7bb64df5461ee0e8550a553ccb34"
SRC_URI[patch0028.md5sum] = "22a0d0c8d19b62394d7e01d8809e2037"
SRC_URI[patch0029.md5sum] = "f1dea8e9f7dc894742a3bf4d5eaac3dd"
SRC_URI[patch0030.md5sum] = "eaba75c4a2aebfef0507dea8e381f6f8"
SRC_URI[patch0031.md5sum] = "639f77648ea39fc8f1cfa6ae3a68b128"
SRC_URI[patch0032.md5sum] = "9688dd6cd7a6895a64427173af54b485"
SRC_URI[patch0033.md5sum] = "a1618f149f5c5dfb1cb41f8f55103db2"
SRC_URI[patch0034.md5sum] = "0deeb7ab9c593e238edd5e07a469873f"
SRC_URI[patch0035.md5sum] = "ec7154d6635fd1b6d2ef4a079db10046"
SRC_URI[patch0036.md5sum] = "d138e12776d0f4c4f70dacab9c5f7853"
SRC_URI[patch0037.md5sum] = "8a73d2adf949c8629a2651ef0fea8d95"
